package auth

import (
	"fmt"
	"gitlab.bob.co.za/bob-public-utils/bobgroup-go-utils/date_utils"
	"testing"
	"time"
)

func TestJWT(t *testing.T) {
	secret := []byte("THISISTHESECRETKEY")

	jwToken := JsonWebToken{
		UserID:     "janoadmin",
		Password:   "Password123",
		ProviderID: 1,
		ExpiryDate: date_utils.CurrentDate().Add(time.Second * 1),
	}

	// Validate before expire
	fmt.Println("TEST VALID JWT")
	jwTokenString, err := GenerateJWT(jwToken, secret)
	if err != nil {
		fmt.Println("!!!!FAIL", err.Error())
		t.FailNow()
	}
	validatedToken, err := ValidateJWT(jwTokenString, secret)
	if err != nil {
		fmt.Println("!!!!FAIL", err.Error())
		t.Fail()
	} else {
		fmt.Println("    SUCCESS", validatedToken)
	}

	// Validate invalid signature
	fmt.Println("TEST INVALID JWT SIGNATURE")
	jwTokenString, err = GenerateJWT(jwToken, []byte("INCORRECTSECRETVALUE"))
	if err != nil {
		fmt.Println("!!!!FAIL", err.Error())
		t.FailNow()
	}
	validatedToken, err = ValidateJWT(jwTokenString, secret)
	if err == nil {
		fmt.Println("!!!!FAIL")
		t.Fail()
	} else {
		fmt.Println("    SUCCESS", err.Error())
	}

	time.Sleep(time.Second * 1)

	// Validate after expire
	fmt.Println("TEST EXPIRED JWT")
	jwTokenString, err = GenerateJWT(jwToken, secret)
	if err != nil {
		fmt.Println("!!!!FAIL", err.Error())
		t.FailNow()
	}
	validatedToken, err = ValidateJWT(jwTokenString, secret)
	if err == nil {
		fmt.Println("!!!!FAIL")
		t.Fail()
	} else {
		fmt.Println("    SUCCESS", err.Error())
	}

	fmt.Println("Done!")
}
